@@ -268,7 +268,8 @@ feis <- function(formula, data, id, weights = NULL, robust = FALSE, intercept =
 
 
   if(utils::packageVersion("dplyr") >= "1.0.0"){
-    dhat <- dplyr::bind_rows(rbind(dhat), .id = NULL) # only for version dplyr >= 1.0.0 keeps rownames
+    dhat <- undim(unclass(dhat))
+    dhat <- dplyr::bind_rows(dhat, .id = NULL) # only for version dplyr >= 1.0.0 keeps rownames
   }else{
     dhat <- do.call(rbind, lapply(dhat, as.matrix)) # use dplyr for more efficiency
   }
